@@ -20,6 +20,8 @@ import traceback
 # Extern Imports
 import tornado.options
 from tornado.options import define, options
+import pympler.muppy
+import pympler.summary
 
 # Project Imports
 import aegis.stdlib
@@ -88,12 +90,18 @@ class HydraThread(threading.Thread):
                 time.sleep(options.hydra_sleep)
 
 
-    # Graceful shutdown with debug
+    # Debug dump in response to kill -SIGUSR1
     @staticmethod
     def signal_debug(sig, frame):
-        """Interrupt running process, and provide a python prompt for interactive debugging."""
+        """Interrupt running process, and provide a stack trace for each thread. Trigger using kill -SIGUSR1 <pid>"""
+        # Show memory usage
+        all_objects = pympler.muppy.get_objects()
+        summary1 = pympler.summary.summarize(all_objects)
+        formatted = pympler.summary.format_(summary1)
+        logging.warning("Received SIGUSR1 - Dumping Debug Output" + "\n".join(formatted) + "\n")
+        # Dump a stack trace on each thread
         id2name = dict([(th.ident, th.name) for th in threading.enumerate()])
-        code = ["Received SIGUSR1 - Dumping Debug Output"]
+        code = []
         for threadId, stack in sys._current_frames().items():
             code.append("\n# Thread: %s(%d)" % (id2name.get(threadId,""), threadId))
             for filename, lineno, name, line in traceback.extract_stack(stack):
@@ -407,7 +415,6 @@ class Hydra(HydraThread):
             traceback.print_exc()
             self.exception_alert(ex)
 
-
         finally:
             self.finish()
 
