@@ -344,7 +344,7 @@ class HydraType(aegis.database.Row):
 
     @classmethod
     def scan(cls):
-        sql = "SELECT * FROM hydra_type ORDER BY next_run_dttm ASC"
+        sql = "SELECT * FROM hydra_type ORDER BY next_run_dttm ASC, status ASC, priority_ndx ASC"
         return db().query(sql, cls=cls)
 
     def run_now(self):
@@ -457,7 +457,10 @@ class HydraQueue(aegis.database.Row):
     @classmethod
     def scan(cls, limit=100):
         # XXX TODO using work_host, work_env
-        sql = "SELECT hydra_queue.*, hydra_type.hydra_type_name, hydra_type.next_run_sql, hydra_type.status FROM hydra_queue JOIN hydra_type USING (hydra_type_id) WHERE finish_dttm IS NULL AND hydra_queue.delete_dttm IS NULL ORDER BY hydra_queue.work_dttm ASC LIMIT %s"
+        if type(db()) is aegis.database.PostgresConnection:
+            sql = "SELECT hydra_queue.*, hydra_type.hydra_type_name, hydra_type.next_run_sql, hydra_type.status FROM hydra_queue JOIN hydra_type USING (hydra_type_id) WHERE finish_dttm IS NULL AND hydra_queue.delete_dttm IS NULL ORDER BY claimed_dttm DESC NULLS LAST, hydra_queue.work_dttm ASC LIMIT %s"
+        elif type(db()) is aegis.database.MysqlConnection:
+            sql = "SELECT hydra_queue.*, hydra_type.hydra_type_name, hydra_type.next_run_sql, hydra_type.status FROM hydra_queue JOIN hydra_type USING (hydra_type_id) WHERE finish_dttm IS NULL AND hydra_queue.delete_dttm IS NULL ORDER BY claimed_dttm DESC, hydra_queue.work_dttm ASC LIMIT %s"
         return db().query(sql, limit, cls=cls)
 
     @classmethod
@@ -720,3 +723,13 @@ class Cache(aegis.database.Row):
     def purge_expired():
         sql = "DELETE FROM cache WHERE cache_expiry < NOW()"
         return db().execute(sql)
+
+
+class AuditSession(aegis.database.Row):
+    table_name = 'audit_session'
+    id_column = 'audit_session_id'
+
+
+class AuditRequest(aegis.database.Row):
+    table_name = 'audit_request'
+    id_column = 'audit_request_id'
