@@ -73,13 +73,13 @@ class AegisHandler(tornado.web.RequestHandler):
         self.tmpl['referer'] = self.request.headers.get('Referer')
         self.tmpl['user_agent'] = self.request.headers.get('User-Agent')
         self.tmpl['scheme'] = 'https://'
-        self.tmpl['get_current_user'] = self.get_current_user
         self.tmpl['xsrf_token'] = self.xsrf_token
         self.tmpl['nl2br'] = aegis.stdlib.nl2br
         self.tmpl['format_integer'] = aegis.stdlib.format_integer
         self.tmpl['get_user_id'] = self.get_user_id
         self.tmpl['get_member_id'] = self.get_member_id
         self.tmpl['get_member_email'] = self.get_member_email
+        self.tmpl['get_current_user'] = self.get_current_user
         self.tmpl['utcnow'] = datetime.datetime.utcnow()
         if self.cookie_get('session'):
             self.tmpl['session_ck'] = self.cookie_get('session')
@@ -105,7 +105,7 @@ class AegisHandler(tornado.web.RequestHandler):
         super(AegisHandler, self).prepare()
         if self._parent_timer:
             aegis.stdlib.timer_stop(self.timer_obj, 'prepare')
-        if options.use_audit and self.audit_ind:
+        if aegis.config.get('use_audit') and options.use_audit:
             self.audit_start()
 
     def finish(self, chunk=None):
@@ -148,7 +148,7 @@ class AegisHandler(tornado.web.RequestHandler):
 
     def on_finish(self):
         # This runs after the response has been sent to the client, intended for cleanup.
-        if options.use_audit and self.audit_ind:
+        if aegis.config.get('use_audit') and options.use_audit:
             self.audit_request_id = self.audit_finish()
 
     def debug_request(self):
@@ -311,6 +311,7 @@ class AegisHandler(tornado.web.RequestHandler):
         cookie_flags = {'httponly': True, 'secure': True}
         if options.hostname == 'localhost':
             cookie_flags['secure'] = False
+        # XXX Way to not set httponly for reading in javascript
         cookie_val = self.cookie_encode(value)
         self.set_secure_cookie(self.cookie_name(name), cookie_val, expires_days=cookie_duration, domain=options.hostname, **cookie_flags)
 
@@ -428,6 +429,7 @@ class AegisHandler(tornado.web.RequestHandler):
             self._member_auth.revoke()
         self.cookie_clear('auth')
         self.tmpl['logged_out'] = True
+        self.audit_session_end()
 
     def email_link_auth(self, email_link_id, token, email_type=None):
         if not aegis.stdlib.validate_token(email_link_id, token):
@@ -516,7 +518,6 @@ class AegisHandler(tornado.web.RequestHandler):
             audit_session_id = aegis.model.AuditSession.insert_columns(**self.audit_session)
             self.tmpl['session_ck'] = {'audit_session_id': audit_session_id}
             self.cookie_set('session', self.tmpl['session_ck'])
-
         # Audit Request
         url_parts = urllib.parse.urlparse(self.request.uri)
         self.audit_request['audit_session_id'] = audit_session_id
@@ -545,7 +546,7 @@ class AegisHandler(tornado.web.RequestHandler):
             self.prepare()
         # Audit Session - takes 10ms !!
         audit_session_id = self.tmpl.get('session_ck', {}).get('audit_session_id')
-        aegis.stdlib.logw(audit_session_id, "AUDIT SESSION ID")
+        #aegis.stdlib.logw(audit_session_id, "AUDIT SESSION ID")
         self.audit_session['member_id'] = self.get_member_id()
         if audit_session_id:
             if self.view_ind:
@@ -595,7 +596,7 @@ class AegisHandler(tornado.web.RequestHandler):
             if render_time_s:
                 self.audit_request['render_time'] = render_time_s * 1000
         audit_request_id = aegis.model.AuditRequest.insert_columns(**self.audit_request)
-        aegis.stdlib.logw(audit_request_id, "AUDIT REQUEST ID")
+        #aegis.stdlib.logw(audit_request_id, "AUDIT REQUEST ID")
         self.save_audit_relations(audit_request_id)
         return audit_request_id
 
@@ -607,6 +608,12 @@ class AegisHandler(tornado.web.RequestHandler):
             model_class, row_id = audit_relation
             model_class.set_audit_request_id(row_id, audit_request_id)
 
+    def audit_session_end(self):
+        # closes the session by deleting the cookie
+        self.cookie_clear('session')
+        if hasattr(self.tmpl, 'session_ck'):
+            del self.tmpl['session_ck']
+
 
 class JsonRestApi(AegisHandler):
     def check_xsrf_cookie(self): pass
